==> piwigo-16.1.0.zip: piwigo/plugins/TakeATour/language/ja_JP/tour_2_9_0.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2017 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['2_9_0_stp4'] = '写真編集ページヘのリンクをダウンロードする、管理者用。';
$lang['2_9_0_stp6'] = 'デフォルトでは、履歴は今月の統計に開放されています。';
$lang['2_9_0_stp7'] = 'タグ管理はバッチアクションを適用するため個別の選択モードを持っています。<br><br>選択モードに切り替えるためにはリンクをクリックして下さい。';
$lang['2_9_0_title5'] = 'チェックサムを複製する';
$lang['2_9_0_stp1'] = '2.9最大の変更点:デザインをどうぞ！暗いヘッダ、フッターとメニューバー、縁の削減。<br><br>"ダッシュボード"と呼ばれる刷新された管理者ホームページは、メインページへ素早くアクセスするための大きなアイコンがあります。';
$lang['2_9_0_stp3'] = '写真を含むアルバムを削除するとき、Piwigoはアルバムに関連する写真をどうしたいのか尋ねるでしょう。<br><br>削除リンクを押して確認してみて下さい（キャンセルできます）。';
$lang['2_9_0_stp5'] = 'チェックサムに基づいて重複写真を見つける（ファイルの中身に基づく厳密な照合）';
$lang['2_9_0_title2'] = 'パスワード生成器';
$lang['2_9_0_title3'] = 'アルバム削除のオプション';
$lang['2_9_0_title7'] = 'タグ選択モード';
$lang['2_9_0_stp2'] = 'バージョン2.9は、ユーザ生成フォームにパスワード生成器を組み込んであります。<br><br>このアクションリンクをクリックして、何が起こるか見て下さい！';
$lang['2_9_0_title1'] = 'Piwigo 2.9 へようこそ';
$lang['2_9_0_title4'] = '写真をダウンロードする';
$lang['2_9_0_title6'] = '今月の履歴';

==> piwigo-16.2.0.zip: piwigo/plugins/TakeATour/language/ja_JP/tour_2_8_0.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2017 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['2_8_0_title1'] = 'Piwigo 2.8 へようこそ';
$lang['2_8_0_title2'] = 'ユーザに知らせる';
$lang['2_8_0_title3'] = '認証鍵';
$lang['2_8_0_title4'] = 'ウォーターマーク';
$lang['2_8_0_stp3'] = '簡単に言えば、認証キーはユーザがパスワードを覚えていなくても良くなるということです。<br><br>それらはプライベートなコンテンツに直接安全にアクセスするでしょう。';
$lang['2_8_0_stp4'] = 'ウォーターマークを数行に渡り繰り返すことができるようになりました。<br><br>繰り返すには<em>Y repeat<em>設定を1または2に設定して下さい。';
$lang['2_8_0_stp5'] = 'アルバムを削除する時、幾つかの写真は孤立するかも知れません。Piwigo 2.8はそれらを明らかにします...';
$lang['2_8_0_stp6'] = '...そしてあなたは1クリックだけでできます！';
$lang['2_8_0_title5'] = '孤立';
$lang['2_8_0_title6'] = '孤立';
$lang['2_8_0_stp1'] = 'ユーザの詳細はユーザリスト中には開かなくなり、シンプルなフォームとなって単一ユーザに集中できます。<br><br>Piwigo 2.8は、ユーザが不正な電子メールアドレスを編集したりチェックした際のユーザリスト更新などのバグを修正しました。';
$lang['2_8_0_stp2'] = '電子メールによるアルバムを通知する時、Piwigo 2.8はグループだけでなくユーザも選択できるようにしました。';
